@@ -1,7 +1,6 @@
 
-vrb = function(...) verbalise(..., verbose = FALSE)
+vrb = function(...) format(verbalise(...))
 
-skip("Wait for next ribd version")
 test_that("verbalise() works in a simple ped list", {
   nuc = nuclearPed()
   x = list(nuc, singleton(4))
@@ -9,15 +8,14 @@ test_that("verbalise() works in a simple ped list", {
   expect_equal(vrb(x, 3:4), vrb(x, 1:2))
 
   expect_error(vrb(x, 5:6), "Unknown ID label")
-  expect_error(vrb(x, 3:5), "Argument `ids` must have length 2")
+  expect_error(vrb(x, 1:3), "Argument `ids` must have length 2")
 
 })
 
-skip("Wait for ribd 1.4")
 test_that("verbalise() gives error in pedlist with duplicated labels", {
   x = list(nuclearPed(), singleton())
   expect_error(vrb(x, 1:2), "ID label is not unique: 1")
 
   # No error for unduplicated indivs
-  expect_match(vrb(x, 2:3)[1], "mother")
+  expect_match(vrb(x, 2:3)[1], "2 is the mother of 3")
 })
